package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````E1<``#0```"(@0````0`!30`(``)
M`"@`&P`:``$``'!\>0``?'D``'QY```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````"(>0``B'D```4```````$`
M`0```*!]``"@?0$`H'T!`*`"``"X$@``!@```````0`"````J'T``*A]`0"H
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DH'T`
M`*!]`0"@?0$`8`(``&`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`!)@KNDW$C0W(GHBM\9)BQN7MF:X$
M````$`````$```!'3E4```````,````"`````````!$```!/````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$\```!0````4P``
M`%<```!8````8````&$```!B````9````&4```!G````:````&D```!J````
M;0```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````H!(````````#``L```````"``0``````
M`P`6`)`"`````````````!(````Q`P`````````````2````!0,`````````
M````(@```$H#`````````````!$```#-`P`````````````2````$0``````
M````````(````-L!`````````````!(```#D`@`````````````2````(@,`
M````````````$@```!$!`````````````!(```!Z`P`````````````1````
MM```````````````$@```*L"`````````````!(```"#`0`````````````2
M````EP(`````````````$@```(0``````````````!(````,`0``````````
M```2````L@(`````````````$@```'0"`````````````!(````Z`@``````
M```````2````5`,`````````````$@```$L"`````````````!(```!8`@``
M```````````2`````0$`````````````$0```&<!`````````````!(```#C
M```````````````1````-0$`````````````$@```.L"`````````````!(`
M``#=`@`````````````1````P@``````````````$@```+$!````````````
M`!(````2`@`````````````2````G@$`````````````$@```,L"````````
M`````!(```#W`0`````````````2````J@$`````````````$@```#@#````
M`````````!(```!#`0`````````````2````+0``````````````(````&T"
M`````````````!(````D`@`````````````2````@@(`````````````$@``
M`+P!`````````````!$```!D```````````````2````]`(`````````````
M$@```),``````````````!(```#@`0`````````````2````%`,`````````
M````$@```)\``````````````!(```!<`0`````````````2````4@(`````
M````````$@```(D"`````````````!(````B`0`````````````2````5@``
M````````````$@```!8!`````````````!(```"3`0`````````````2````
MG0(`````````````$@```/```````````````!(```!F`@`````````````2
M````*@,`````````````$@```'L"`````````````!(```!U`0``````````
M```2````<P``````````````$@```$L#`````````````"$```#[`@``````
M```````2````U```````````````$@```%,!`````````````!(````\````
M```````````@````3`,`````````````$0```-,"`````````````!(````I
M`@`````````````2````8`(`````````````$@```/$!`````````````!(`
M``#``@`````````````2````,0(`````````````$@```/X!````````````
M`!(```#J`P``6)`!```````0`!<`U@,``$$L``!0````$@`-``X$```%)```
M9`4``!(`#0!%`P``R14``,P!```2``T`G`,``+4>```$````$@`-`*T#``!`
M@`$``````!``%P"J!```N1X``,@!```2``T`X`0``&DI``#8`@``$@`-`)8$
M``!`@`$``````!``%P#U`P``@2```!8````2``T`&P0``*$Y``#F````$@`-
M`#,$``"D.P``!````!$`#P!R!```6)`!```````0`!<`=P0``%B0`0``````
M$``7`*($``"-'0``.````!(`#0"W!```62,``*P````2``T`R00``-4B``!T
M````$@`-`"8$````@`$``````!``%@`"!```F2```+0````2``T`X@,``$"`
M`0``````$``6`&@$```\@`$`!````!$`%@",`P``B3L```(````2``T`6`0`
M`$D[``!`````$@`-`"P$``"5%P```````!(`#0#7!```)3D``'P````2``T`
M*`0```"``0``````(``6`+L#``!)(P``$````!(`#0#I`P``6)`!```````0
M`!<`0@0``!$>``"D````$@`-`(P$``").@``O@```!(`#0!_!```32$``(@!
M```2``T``&QI8G!E<FPN<V\N-2XS,`!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`')E860`7U]E<G)N;U]L
M;V-A=&EO;@!C;&]S90!O<&5N-C0`<'1H<F5A9%]G971S<&5C:69I8P!L<V5E
M:S8T`&QI8F,N<V\N-@!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C:U]C
M:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T
M<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`
M7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T
M`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`<W1R
M8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE
M;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER
M;VX`7U]R96=I<W1E<E]A=&9O<FL`;&0M;&EN=7@M87)M:&8N<V\N,P!?7W-T
M86-K7V-H:U]G=6%R9`!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R
M7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T
M`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?
M8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`
M<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A
M<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT
M97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````````"``(``@`"``(````#
M``(``@`"``0````"`````@```````@`"``(``@`"``(````````````"``(`
M``````,````"``,``@`"```````"``(``@```````@````,``@```````@`"
M`````````````@````(``@`"```````"``(``````````@`"``(``@`#``(`
M`@`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!`&8#```0````(````!1I:0T```0`
M]@0````````!``$`RP$``!`````@````%&EI#0```P#V!`````````$``0`:
M`@``$``````````4:6D-```"`/8$````````H'T!`!<```"D?0$`%P```,!_
M`0`7````Z'\!`!<```#P?P$`%P````2``0`7````#(`!`!<````0@`$`%P``
M`!B``0`7````'(`!`!<````@@`$`%P```"2``0`7````*(`!`!<````P@`$`
M%P```#2``0`7````/(`!`!<```#$?P$`%04``,A_`0`5"```S'\!`!4-``#0
M?P$`%1```-1_`0`5&@``V'\!`!4<``#<?P$`%1\``.!_`0`5*0``Y'\!`!4M
M``#L?P$`%3<``/1_`0`500``^'\!`!5&``#\?P$`%4<``,1^`0`6`P``R'X!
M`!8$``#,?@$`%@4``-!^`0`6!P``U'X!`!8)``#8?@$`%@H``-Q^`0`6"P``
MX'X!`!8,``#D?@$`%@X``.A^`0`6#P``['X!`!81``#P?@$`%A(``/1^`0`6
M$P``^'X!`!84``#\?@$`%A4```!_`0`6%@``!'\!`!87```(?P$`%A@```Q_
M`0`6&0``$'\!`!8;```4?P$`%AT``!A_`0`6'@``''\!`!8@```@?P$`%B$`
M`"1_`0`6(@``*'\!`!8C```L?P$`%B0``#!_`0`6)0``-'\!`!8F```X?P$`
M%B<``#Q_`0`6*```0'\!`!8I``!$?P$`%BH``$A_`0`6*P``3'\!`!8L``!0
M?P$`%BX``%1_`0`6+P``6'\!`!8P``!<?P$`%C$``&!_`0`6,@``9'\!`!8S
M``!H?P$`%C0``&Q_`0`6-0``<'\!`!8V``!T?P$`%C@``'A_`0`6.0``?'\!
M`!8Z``"`?P$`%CL``(1_`0`6/```B'\!`!8]``",?P$`%CX``)!_`0`6/P``
ME'\!`!9```"8?P$`%D,``)Q_`0`61```H'\!`!9%``"D?P$`%D@``*A_`0`6
M20``K'\!`!9*``"P?P$`%DL``+1_`0`63```N'\!`!9-``"\?P$`%DX```A`
M+>E,`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7\:P$``,:/XA;*C.+\^[SE`,:/
MXA;*C.+T^[SE`,:/XA;*C.+L^[SE`,:/XA;*C.+D^[SE`,:/XA;*C.+<^[SE
M`,:/XA;*C.+4^[SE`,:/XA;*C.+,^[SE>$?]YP#&C^(6RHSBP/N\Y0#&C^(6
MRHSBN/N\Y0#&C^(6RHSBL/N\Y0#&C^(6RHSBJ/N\Y0#&C^(6RHSBH/N\Y0#&
MC^(6RHSBF/N\Y0#&C^(6RHSBD/N\Y7A'_><`QH_B%LJ,XH3[O.4`QH_B%LJ,
MXGS[O.5X1_WG`,:/XA;*C.)P^[SE`,:/XA;*C.)H^[SE`,:/XA;*C.)@^[SE
M`,:/XA;*C.)8^[SE`,:/XA;*C.)0^[SE`,:/XA;*C.)(^[SE`,:/XA;*C.)`
M^[SE`,:/XA;*C.(X^[SE`,:/XA;*C.(P^[SE`,:/XA;*C.(H^[SE`,:/XA;*
MC.(@^[SE`,:/XA;*C.(8^[SE`,:/XA;*C.(0^[SE`,:/XA;*C.((^[SE`,:/
MXA;*C.(`^[SE`,:/XA;*C.+X^KSE`,:/XA;*C.+P^KSE`,:/XA;*C.+H^KSE
M`,:/XA;*C.+@^KSE`,:/XA;*C.+8^KSE`,:/XA;*C.+0^KSE`,:/XA;*C.+(
M^KSE`,:/XA;*C.+`^KSE`,:/XA;*C.*X^KSE`,:/XA;*C.*P^KSE>$?]YP#&
MC^(6RHSBI/J\Y0#&C^(6RHSBG/J\Y0#&C^(6RHSBE/J\Y0#&C^(6RHSBC/J\
MY0#&C^(6RHSBA/J\Y0#&C^(6RHSB?/J\Y0#&C^(6RHSB=/J\Y0#&C^(6RHSB
M;/J\Y0#&C^(6RHSB9/J\Y0#&C^(6RHSB7/J\Y0#&C^(6RHSB5/J\Y0#&C^(6
MRHSB3/J\Y0#&C^(6RHSB1/J\Y0#&C^(6RHSB//J\Y0#&C^(6RHSB-/J\Y0#&
MC^(6RHSB+/J\Y0#&C^(6RHSB)/J\Y0#&C^(6RHSB'/J\Y0#&C^(6RHSB%/J\
MY0#&C^(6RHSB#/J\Y0#&C^(6RHSB!/J\Y0#&C^(6RHSB_/F\Y0````#PM8FP
M7$Q=2WQ$!9`$D06H`Y($J>-8`ZI93!MH!Y-/\``#__="[U=*?$172Z)8X%@1
M1@+PQ_I52^-8'G@`+FW04TOE6"AH__?4[P-&*&B3^,8C0O`"`H/XQB/_]\KO
M!9L%,[/Q@$^0^,8C0O`!`H#XQB-VTI@`!"3_]]KN14D$GGE$14H/:'I$-6A$
M27E$`T9#2,/I`2<%FGA$P>D!0P$J'6#"OS$=`_$,!`;K@@;88`7=4?@$6XY"
M1/@$7_G1`O&`03A-`S$`)'U$`)1#^"%``S(U22AI>43_]RKO!$9HLS)-!JY]
M1"AI__=^[C!(,49X1`#P\_@PLRY+>T08:?_W1N[_]PKO+$H<2WI$TU@::`>;
M6D`NT2!&";#PO?_W?.XF2GI$$&$0L__W*NX82^58*&C_]U[O@/AQ9X/G*&G_
M]R[O!$;,Y^AH$+$!\)7ZT^<;2#%&>$0`\,'XZ&``*,O0\^<82QA(X5AX1/_W
MO.X!(/_WCN[_]Q[NY&@!`!0!``#$:`$`-`$``#P!```@`0``'`$``/!I`0"*
M*```[&D!`'PH``"P:0$`(P<``)1I`0#H)0``?FD!`.)G`0!6:0$`("4``"P!
M``#D)@``3_``"T_P``X"O&I&!+0!M-_X)*`(HYI$W_@@P%KX#,!-^`3-!DM:
M^`,P!DA:^```__<P[O_WWN[L9@$`"`$``#`!```X`0``%#"?Y10@G^4#,(_@
M`B"3YP``4N,>_R\!$?__ZLQF`0`H`0``!D@'2WA$!TI[1(-">D0#T`5+TU@#
ML1A'<$<`OSAH`0`T:`$`J&8!`!`!```(2`E)>$0)2GE$"1IZ1,L/`^NA`4D0
M`]`%2]-8`[$81W!'`+\,:`$`"&@!`'QF`0!``0``"+4*2PI*>T1Z1!MX:[D)
M2]-8([$(2WM$&&C_]R[M__>__P9+`2)[1!IP"+W69P$`3&8!``P!``"*9P$`
MMF<!`,3G`+\MZ?A#@48@2WM$`"@WT!]*FUC3^`"`N/$`#S+0`G@/1K+Q/048
MOP$E`"H(OP`EG;G8^`!`;+%&1BI&248@1O_W3.X0N6-=/2L0T%;X!$\`+/+1
M($:]Z/B#!485^`$_`"L8OSTK^=&EZPD%X><!-:;K"`8L1+80/F`@1KWH^(,$
M1N?G1$;EYP"_"&8!`$0!```:2AM+>D1PM8*PTU@$1AE-;D8;:`&33_```WU$
M,48@1O_WIO^PL11+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$Q
M1B!&__>0_P`HZ-$)2@9+>D336!IH`9M:0`'1`K!PO?_W[NQ\90$`%`$``&9E
M`0!$`0``*&4!`"WI\$\,1@MX@[!8205&6$H]*WE$"+\!--_X6(&*6"!&^$02
M:`&23_```O_W0NUI1@9&*$;_]US_@48`*%?0__<X[;!"2M),2P"?6/@#@+\`
M*'BP\3T"&+\!(@`H"+\`(CJQ*D82^`$_`"L8OSTK^=%2&[`<V/@`8!!$__?V
M[/!1`"AKT-CX`"`H1@"9$/@!.U+X(1`]*QB_`"L+<`G02AP0^`$[$48`*QB_
M/2L"^`$[]M$*1CTC"W`4^`$[`O@!/P`K^=$`("U**4MZ1--8&F@!FUI`2-$#
ML+WH\(\)\?\Y%/@!.PGX`3\`*_G1ZN<B2UCX`X#8^`"@VO@`,(NS4T93^`0O
M248)\0$)`"KXT0,QB0`;2GI$$VBSN0A&`2,38/_WHNR#1LBQ3^J)!U%&.D;_
M]Q#LR/@`L`GQ`0,`(DOX(R#-^`"0@^=01D_JB0?_]U#L@T;(^````"CMT4_P
M_S"QYYE&""'4Y__W+NSN9`$`%`$``.!D`0!$`0``-F0!`'AE`0`Z2CM+>D0M
MZ?!!GK#36!MH'9-/\``#$+$#>`1&4[DU2C-+>D336!IH'9M:0%S1'K"]Z/"!
M__=*[`5&`"COT"Y/?T0H1O_WYNR@L\-\`/$3""XK-M##?"XK.M`@1O_W9NP&
M1D!&__=B[#!$`C#_]SKL.T9/\/\R`2'-^`2``)0&1O_W<NP"JC%&`R#_]];L
M`3`P1@70!IL#]'!#L_6`3R#0__?>ZS!&__><ZRA&__>R[``HRM$H1O_WWNP@
M1O_WHNNMYYCX`3``*[O0PWPN*\31F/@!,"XKP-&8^`(P`"NPT+OG__>-_]WG
M__>LZWAC`0`4`0``6F,!`&@@``#?^&#`&$O\1!"UG+`$1ESX`S!J1@,@(48;
M:!N33_```__WI.R0N02;`_1P0[/U($\8O[/U@$\+T`Q*"TMZ1--8&F@;FUI`
M"]$<L!"]`"#SYR!&`B'_]T[LL/J`\$`)Z^?_]W+K>F(!`!0!``!$8@$`W_C,
MP$#V_W(MZ?!#K?6`73!,@[#\1`&N!48O2%SX!$`-]8!3>$0/1C%&!#,D:!Q@
M3_``!/_W=NLH2RE*>T0$'CC=!/'_.)M8%O@($-/X`)`!N[CQ``\ET$)&+R$P
M1O_W#.SXL4A&__=6[$-&,D8I1O_W(.P;20WU@%,62@0S>42*6!%H&FA10!_1
M#?6`70.PO>CP@Z!&+R%"1C!&__?LZP`HW]%(1O_W-NPZ1BE&__<TZ]_GFUC3
M^`"02$;_]RKL.D8I1O_W*.O4Y__W!NL`O_QA`0`4`0``(!\``-1A`0`<`0``
MDF$!`!"U"$P(2WQ$XU@8:/_W#NP&2@=+!TFB6'M$O>@00'E$__>$NR)A`0`<
M`0``&`$``*1;``!.'@``#4L.2GM$$+6"L)Q8(&C_]_+K__?9_R!H__?LZPA+
M`"$(2GM$S>D`,0=)>D1Y1/_WCNL"L!"]`+_L8`$`'`$``.X@``!W"P``)!X`
M`"-))$IPM7E$K?4`78:PBE@-]0!3`ZP4,Q)H&F!/\``"__<,ZQQ+#?6`5D'R
M`0)[1`&3&DL0-@$A>T0`D"!&__<HZR!&,49/](!2__>VZ@0>N+\`)0K;8!S_
M]]CJ!48HL3%&(D;_]USJ`",K50Q)#?4`4PA*%#-Y1(I8$6@::%%`!-$H1@WU
M`%T&L'"]__=NZIY@`0`4`0``^AT``.0=```N8`$`__>LORWI\$^M]81=8DR#
ML&)*!49\1&)(!JX-]813HEAX1(A&,48$,Q)H&F!/\``"__?>_"\A!$8H1O_W
MQNJPL5A(*49X1/_W6_TH1E9)#?6$4U)*!#-Y1(I8$6@::%%`0/"8@`WUA%T#
ML+WH\(\H1O_WGNI-27E$!T9`1O_W`.N"1@`HW-!*2]_X*)%[1`63FO@`,/E$
MW_@@@?A$`"M0T"RQ448@1O_WN.D`*%704$;_]W[J`/'_/(9&"NL,`QKX#!`O
M*1#1@AZLZP,,4D091M(:3_``"X/X`+`#ZPP.$?@!#1-$+RCVT'L<GD2^]8!?
MIMH-\80+,4H!(4-&>D181@&23_2`4@*5S?@`H/_W;NHR1EE&`R#_]]+J*+DS
M:0/T<$.S]0!/(M`E20`@>43_]ZCJ@D:Z\0`/@M":^``P`"NNT1RS(W@N*P30
MW?@4H$_P`0[)YV-X`"OWT1I)`"!Y1/_WCNJ"1KKQ``_FT6CG`2%81O_W@.H`
M*-;1$TA91GA$__>^_%A&__>:Z5_GRD9/\`$.J>?_]YCI[%\!`!0!``!H'0``
M4!T``*I?`0`N'0``;!P``&0<```.'0``M!P``'@<``!&'```%AP```-X.[%"
M'"\K"+\01A+X`3L`*_C1<$<`OQ"UN+,#>`1&H[/_]^#I0QXC1)Q".+\:1@/3
M,>"B0A-&+M`31A+X`1DO*??0G$(GT@$[G$(FT!IX+RKYT0$[`N`1>"\I!-&<
M0AI&`_'_,_?3$AN3'+/U@%^(OP`@"=@12"%&`3)/](!3>$0$1O_W+.D@1A"]
M#$B]Z!!`>$3_]RJYG$+;T1MX+RL%T`A(O>@00'A$__<?N09(O>@00'A$__<9
MN0"_5%\!`)H:```\&P``>!H``$=*\+5Z1$=,C;!'2P*M?$1&3PPT`:[36']$
M&V@+DT_P``,/S`_%#\P/Q21H0$AX1"R`__?9^S](>$3_]]7[/DAX1/_WT?L]
M2'A$__?-^SQ(>$3_]\G[.TAX1/_WQ?LZ2'A$__?!^SE(>$3_][W[.$;_][K[
M-DAX1/_WMOLU2'A$__>R^S1(,49X1/_W9?L8L0%&.$;_]^C[,$@Q1GA$__=;
M^P%&&+$N2'A$__?=^RU(,49X1/_W4/L!1IBQ*DAX1/_WTOLI22I(>41X1/_W
MS/LH2A5+>D336!IH"YM:0!W1#;#PO21(,49X1/_W-?L!1B"Q(DAX1/_WM_OC
MYR!)#?$9``HB>43_]Y3I`"C:T1U(#?$C`7A$__>G^]/G__>(Z&1=`0#N5P``
M%`$``%0;``#N&@``\!H``/`:``#T&@``]!H``/P:``"0&@``^!H```(;``!^
M&@``_!H``/P:``"\&0``^AH``#(:```4&P``>AH``)1<`0#4&@``;!H``,P:
M``!,&@``%DL727M$%TH`M7E$&&B#L(I80QP2:`&23_```@K0$DH02WI$TU@:
M:`&;6D`3T0.P7?@$^PU(:49X1/_WR?HPL0!X,"@8OP`H%+\!(``@"$M[1!A@
MX^?_]RCH`+\L70$`UEL!`!0!``"^6P$`H!D``.!<`0`(M?[WV._^]\KO`+$`
M:`B](TKPM7I$(TZ'L"-+!*E^1`5&TU@P1AMH!9-/\``#__>5^BE&$+$#>`1&
M:[D;2'A$__<4^QI*&$MZ1--8&F@%FUI`(M$'L/"]_O>.[P`H\=$H1O_W7.@'
M1B!&__=8Z#A$`C#_]S#H#TM/\/\R`2%[1`&3#4L"E'M$`)4'1O_W9.@Y1C!&
M__?J^M3G_O?,[P"_6%L!`,89```4`0``IAD``"1;`0"2&```CA@``"WI\$^M
M]0%-W_C01(&PW_C0Y`WU@'A\1`:0(QW?^,1D_D0$\1`,D^@'``WU`$->^`9@
MJ/%T!_PSJ/%<!39H'F!/\``&*#2'Z`<`J/%H";SH#P"H\>`&W_B0M/M$#\6<
MZ`,`A>@#`)3H!P")Z`<`,4;?^'@$>$3_]Q/Z(+$#>`1&`"M`\&V!__==_P5&
M`"@`\#6!*$;^]^3O0``!,/[WO.\J>(%&@K'?^$BD3$;Z1"!&`))31D_P_S(!
M(0(T_O?N[Q7X`2\`*O+1W_@H!*CQ6`5X1`+@5?@$"XBQ,4;_]^#Y!$8`*/;0
M`W@`*_/0__>@^P`H[]`@1O[W.N\#1IBY`"57^"5`=+$C>&.Q($8!-?_WC_L`
M*/30($;^]RCO`"COT`-&`.``(QA&!Y/^]YKO\DU]1`1&2$;^]Y3O($0`\@1$
M($;^]VKO!YO?^+##3_#_,@$AS?@,D`"3_$3I2\WI`5Q[1`=&_O>:[SA&3_3@
M<?[WJN\!,`71_O>,[P)H$2I`\."`,D8Y1@,@__<(Z`5&\+'<2@$A!IL`)EOX
M`@#:2AMH>D0`EP!H_O>L[]A)#?4`0\Q*_#-Y1(I8$6@::%%`0/"*@3!&#?4!
M30&PO>CPCS-I`_1P0[/U@$_:T=;X&)#^]XSN@474T3-IP_,(`[/UX'_.T2!&
M_O<0[S%&`T;$2!Y&>$3_]TWY`"@`\+F`!IL<:/[WK.X!1B!&__=,_(%&`"@`
M\*V`2$;^]QSO`R@$1@_9N$D$.$A$>43^]T;N0+D$+`#P!8%,1!3X!3PO*P#P
M_X#_]S[^.+D!1DA&_O?8[@1&`"A`\)"`K$FL2'E$K$QX1-_XL*+_]YSYW_BL
MDO[WY.ZJ2]_XK()\1'M$`9.I2T_P_S(!(0"7>T0#E/I$^43X1`*0,$;^]_KN
M%.#^]_+N`V@1*Q?1_O?([@$U(D931@$AS?@0D,WX!(``E\WI`@4P1O[WY.Y/
M].!Q,$;^]_3N0QP$1N+0.$;^]Q;NDT@Q1GA$__=>^3!&__<M_E;G@D99^"H`
M`"@ST#%&"O$!!?_WR/@)ZX4$JD8(L0-X8[E4^`0+*+,Q1@$U__>[^*I&`"CU
MT`-X`"ORT/[W&NX`*-_0!4:GYG!(`2$&FP`F6_@``!MHS>D`<GE*`&AZ1/[W
MTNXDY__W^/T@1O[W`NX&1AWG#2!S3?[W4NY3(GU$@4:3Y@:;T_@`D$[GJ/$$
M"4_P_S-O\!$"`B4`E?[W*.Y)1@8B($;^]Z3M&/@$/!NYF?@!,$,K8M``(0`B
M`",@1@"1_O<4[@'PKO@%1@/@248H1@'PYOA/]`!"248@1O[WB.T"'O/<($;?
M^&"A_O?4[JCQ1``I1JCQ,`D!\$;YJ/%%!?I$J/$Q"$Q&NT85^`%_($931D_P
M_S(!(0(T`)?^]T#NJ$7RT4E(3_#_,DE+`2%X1,WX")`#D'M$S?@`L#!&`9,`
M(XGX*#!?1D)+>T3^]RCN2N<&FUQH`"P_]/RN($;^]P+N`RA_]O:N.TD$."!$
M>43^]RSM`"@(OZ%&Z^:9^`(P02N8T9GX`S!#*Y31F?@$,$@KD-&9^`4P12N,
MT4_P_S-O\#D"($8`E?[WH.U)1B!&*2+^]Q[M*4LI3$_P_S)[1`&3*$M\1`$A
M,$9[1,WX")``EP.4_O?D[0;G_O=0[0"_ZEL!`)!:`0`4`0``5EH!`,07``"4
M&```W!8``#`7``#\%P``Z!<``"0!``#X%P``_%@!`.P7``"^%P``NA8``#H6
M``!*&```BA<``#08``#8%0``PA4``'X7``!*%0``!!8``,`5``!$%0``IA8`
M`"X4``"^%0``DA4``*83```0%@``/A4``"WI\$^<22WM`HN<2GE$G$N*6(6P
M>T0"KA)H`Y)/\``"F$H([A!JG5@H:/[W$NX$1BAH_O<.[I3X:"`Q1@-&DDB#
M^&D@>$3^]WG_&+$#>#$K`/#N@/_WQOLH:/[W^NV+20LC`2)Y1/[W,NT`*`#P
MTH"'2P%I>T35^`"P6VC1^!B``2M%W=_X#*)/](!I@DO`\B`)^D0`)'M$`),F
MX`)H9AS:^`@`U?@`L)%H4/@F<`GJ`0&Q]8!O"+\1:0S06$8!D_[WQNT!FP`B
M&6@"(_[WSNS5^`"P`48X1O[W1.P`FUMHF+D"-)Q"-$8/VEA&_O>P[0`C(D9!
M1O[W<.T#1@`HS=%F2]7X`+![1%MH61ZA0G#06$;^]Y[M8DD#(P$B>43^]];L
M!$9PL2AH_O>2[2-I74H9:'I$_O>.["-I&VB;:%L"`/&&@"AH_O>$[5=)`R,!
M(GE$_O>\[`1&@+%42!CN$!IX1/[WZ_X&1BAH`"YET/[W<.TC:3)&&6C^]VSL
M*&C^]VCM!$8H:/[W9.U)20$B>43^]\;L1TIZ1`%&($;^]UKL*&C^]U;M`"(8
M[A`:0DU]1`-&0DB#^&D@>$3^][_^!$;H8%"S3_3@<2!&_O?*[$,<$2@8OP$K
M1=@Y2BA+>D336!IH`YM:0#O1!;"][`*+O>CPCP$KC-TS3@$D6$9^1`#@*&C^
M]R;M04;^]]CK<V@!-*-"]=S5^`"P>N>H:/_W/OP$1NA@`"C-T2=(>$3^]XKL
M0W@`*S_T$*\,Y_[W"NTC2R)I>T2;:!!H&6C_]W?XE><H:/[W_NPC:1EH_O>4
M[''G_O?8ZQI)`T8:2")&>41X1(EH"6C^]V;L0%4!`!0!```X50$`'`$``.02
M``!P%```9%8!`$96`0!"5@$`TE4!`,`3``"N$P``M!,``(`1``!:$P``:A,`
M`"I5`0`<$0``<%,!`-Q4`0#>$@``EE0!`&Q4`0"^$@``.+4%1O_W*/H#>`1&
M.[%"'"\K"+\41A+X`3L`*_C1__<Y^P`M&+\`*`#1.+TK>``K^]`&22!&!")Y
M1/[W@.P`*//1*$:]Z#A`_O=6O^`0```MZ?!/K?4C?=_X?$P`\4`!W_AX/&Y&
M?$0`\8`,,D8`)^-8&VBADT_P``-1Z0)4"#%A15=@+;K78$_J%"-/Z@0N`_1_
M0P[T?PY#ZA1C%6!#Z@1C`O$0`D/J#@-"^`@\Y-$&]?QVK?$(!``GAD:D1E3X
M"`_<^'`@W/A(,+1"W/@84-SX=!"#Z@(#W/A,((/J!0/<^!Q0@^H``X+J`0)A
M:(+J!0)/ZM-U@NH!`L3XA'!%ZD(%1>I#`\3X@##7T=[I`L-P1M[I`')/ZIP.
M!FF%:4[J@WYK1OD.'&B&Z@4)1_:9$P5JQ?:"(T'J0A'D&$'J1Q%E&0GJ#`E)
M&85I3NJ,?@*<B>H%";T(ANH."$7J@G6":1'K"0$(Z@<(Y!A%ZH=UB.H&"*08
M!)I/ZO%I%.L(!([J!0@4ZPD$".H!"-(83^JQ`8CJ#@C=^!B0DAE/ZO1J$NL(
M`H7J`0@2ZPH"".H$"!GK`PE/ZK0$B.H%"!GK#@[=^""03^KR:A[K"`Z!Z@0(
M'NL*#@CJ`@@9ZP,)3^JR`HCJ`0@9ZP4%W?@HD$_J_FH5ZP@%A.H""!7K"@4(
MZ@X(&>L#"4_JO@Z(Z@0(W?@PH!GK`0$1ZP@!@NH."4_J]6@)Z@4)$>L("!KK
M`PI/ZK4!B>H""1KK!`3=^#B@CNH!!13K"01/ZOAI!>H(!13K"00:ZP,*3^JX
M"(7J#@4:ZP("W?A`H%(9@>H("4_J]&4)Z@0)51D:ZP,*"D8:ZPX.3^JT`=WX
M2*")Z@($3^KU:1[K!`2(Z@$.%.L)!`[J!0X:ZP,)3^JU!1GK`@F.Z@@.0D;=
M^%"`3^KT:AGK#@Z!Z@4)'NL*#@GJ!`D8ZP,(W?A8H!CK`@A/ZK0"B>H!!!CK
M!`1/ZOYIA>H""!3K"00(Z@X(&NL#"4_JO@X9ZP$)B.H%""E&&)U/ZO1J&>L(
M"(+J#@D8ZPH(">H$">T8W?AHH&T83^JT`8GJ`@1/ZOAI+!F.Z@$%%.L)!`7J
M"`4:ZP,)3^JX"!GK`@ER1MWX<.!50$_J]&H9ZP4%@>H("17K"@4)Z@0)'NL#
M#MWX>*`>ZP(.3^JT`HGJ`00>ZP0$3^KU:8CJ`@X4ZPD$#NH%#AKK`PE/ZK4%
MCNH(#AGK`0E!1MWX@(!/ZO1J&>L."8+J!0X9ZPH)#NH$#ACK`PA/ZK0$CNH"
M#ACK`0'=^(B`3^KY:A'K#@&%Z@0.$>L*`0[J"0X8ZP,(3^JY"8[J!0X8ZP("
MW?B0@$_J\6H2ZPX"A.H)#A+K"@(.Z@$.&.L#"$_JL0$8ZP4%CNH$"-WXF.!/
MZO)J%>L("(GJ`048ZPH(%4`>ZP,.A>H)!2B;'NL$#D_JL@(>ZP4.3O:A-$_J
M^&7&]MED'NL%#H'J`@4;&87J"`43ZPD)*IM/ZK@(&>L%"4_J_F49ZP4)@NH(
M!1L9A>H.!5L8+)E/ZKX.6QE/ZOEE6QF(Z@X%"1F%Z@D%B1@NFD_JN0E-&4_J
M\V%M&([J"0$2&5E`$NL("#":3^JS`QCK`0%/ZO5HB>H#"A'K"`$2&=WXR("*
MZ@4*$NL.`D_JM05/ZO%N$NL*`A+K#@*#Z@4*&.L$#HKJ`0K=^-"`'NL)#D_J
ML0%/ZO)I'NL*#MWXZ*`>ZPD.A>H!"1CK!`B)Z@()&.L#`]WXV(`3ZPD)3^JR
M`T_J_F(9ZP("@>H#"1CK!`B)Z@X)&.L%"#B=3^J^#ACK"0A/ZO)I&.L)"(/J
M#@DM&8GJ`@EI&$_JL@41ZPD!3^KX8HD8CNH%"1KK!`*)Z@@)W?CPH-(8$NL)
M`D_JN`-/ZO%HA>H#"1+K"`(:ZP0(B>H!"=WX^*`8ZPX(3^JQ`4_J\FX8ZPD(
M&.L."(/J`0D:ZP0.B>H""1[K!0Y`G4_JL@(>ZPD.3^KX:=WX"*$>ZPD.@>H"
M"2T9B>H(">L83^JX!1/K"0-/ZOYH$^L(`X+J!0D:ZP0(B>H."=WX$*$8ZP$!
M$>L)"4_JO@%/ZO-NA>H!"!GK#@D:ZP0.'NL"`HCJ`PC=^!CA$NL("$_JLP)/
MZOEC&.L#"('J`@H>ZP0#BNH)"MWX(.%=&17K"@5/ZKD#3^KX:17K"06"Z@,)
M'NL$#HGJ"`D>ZP$!W?@HX4_JN`@1ZPD!3^KU:1'K"0&#Z@@)'NL$#HGJ!0D>
MZP(.3)I/ZK4%'NL)#D_J\6D>ZPD.B.H%"1(9B>H!"=(83IM/ZK$!$NL)`D_J
M_FD2ZPD"A>H!"1L9B>H."1/K"`3=^$"!3^J^#D_J\FH4ZPD$2_;<0\CV&W,4
MZPH$0>H."1CK`PBJ1@GJ`@E/ZK(%&.L*`@'J#@K=^$B!2>H*"4[J!0H2ZPD"
M3^KT:1+K"0(*Z@0*#NH%"1CK`PA/ZK0$2NH)"ACK`0'=^%"11>H$"!KK`0%/
MZO)J".H""!'K"@$%Z@0*&>L#"4CJ"@@9ZPX.3^JR`ACK#@[=^%B!1.H""D_J
M\6D>ZPD."NH!"@3J`@D8ZP,(3^JQ`4KJ"0H8ZP4%W?A@D4+J`0@:ZP4%3^K^
M:@CJ#@@5ZPH%`NH!"AGK`PE(Z@H(&>L$!$_JO@X8ZP0$W?AH@4'J#@I/ZO5I
M%.L)!`KJ!0H!Z@X)&.L#"$_JM05*Z@D*&.L"`MWX<)%.Z@4(&NL"`D_J]&H(
MZ@0($NL*`@[J!0H9ZP,)2.H*"!GK`0%/ZK0$&.L!`=WX>(%%Z@0*3^KR:1'K
M"0$*Z@(*!>H$"1CK`PA/ZK("2NH)"ACK#@[=^("11.H""!KK#@Y/ZO%J".H!
M"![K"@X9ZP,)!.H""D_JL0%(Z@H*&>L%!=WXB)%"Z@$(&NL%!4_J_FH5ZPH%
M".H."`+J`0H9ZP,)3^J^#DCJ"@@9ZP0*9)Q!Z@X)3^KU:QCK"@@)Z@4)&.L+
M"`'J#@KD&$_JM05)Z@H*I!AFFD[J!0D:ZP0$3^KX:A3K"@0.Z@4+$NL#"@GJ
M"`E/ZK@"2>H+"1KK`0AHF47J`@H9ZP@)3^KT:`KJ!`H9ZP@)R1@%Z@((3^JT
M!$KJ"`@1ZPX.:IE"Z@0*&.L.#D_J^6@>ZP@.`NH$"\D8"NH)"D_JN0A-&4KJ
M"PELF43J"`H9ZP4%3^K^:0KJ#@H5ZPD%!.H("<D83^J^#HD82NH)"FZ:2.H.
M"QKK`0E/ZO5J&>L*"0OJ!0'2&`CJ#@M/ZK4%0>H+"Q(9<)E.Z@4*3^KY9!OK
M`@(*Z@D*$AD.Z@4+R1A/ZKD$$>L("$KJ"PERF47J!`H9ZP@(3^KR:1CK"0@%
MZ@0+$>L#"0KJ`@I/ZK(!2NH+"G2:&>L.#AKK#@Y$Z@$)3^KX:@GJ"`D>ZPH.
M!.H!"M(83^JX"$GJ"@E2&7:=0>H("AGK`@)/ZOYI$NL)`@KJ#@KM&`'J"`-*
MZ@,*+1EXFT_JO@X:ZP4%3/+6%$_J\FK,]F(D%>L*!8CJ#@D;&8GJ`@E9&'J;
M3^JR`D_J]6H1ZPD!CNH""1'K"@$;&8GJ!0D3ZP@(?)M/ZK4%&.L)"$_J\6D8
MZPD(@NH%"1L9B>H!"1/K#@Y^FQ[K"0E/ZK$!3^KX;H7J`0H9ZPX.&QF:&(KJ
M"`J`FT_JN`@2ZPH*3^K^8AKK`@*!Z@@)&QF)Z@X)71F"FQ7K"0E/ZKX.3^KR
M91GK!06(Z@X)&QF)Z@()61B$FQ'K"0E/ZK("3^KU81GK`0&.Z@()&QF)Z@4)
M$^L("(:;&.L)"4_JM05/ZO%H&>L("(+J!0D;&8GJ`0D3ZPX.B)L>ZPD)3^JQ
M`4_J^&X9ZPX.A>H!"1L9B>H("9H8BIL2ZPD)3^JX"$_J_F(9ZP("@>H("1L9
MB>H."5T9C)L5ZPD)3^J^#D_J\F49ZP4%B.H."1L9B>H""5D8CIL1ZPD)3^JR
M`D_J]6$9ZP$!CNH""1L9B>H%"1/K"`B0FQCK"0E/ZK4%3^KQ:!GK"`B"Z@4)
M&QF)Z@$)$^L.#I*;'NL)"4_JL0%/ZOAN&>L.#H7J`0D;&8GJ"`F:&)2;$NL)
M"4_JN`A/ZOYB&>L"`H'J"`D;&8GJ#@E=&9:;%>L)"4_JO@Y/ZO)E&>L%!8CJ
M#@D;&8GJ`@E9&)B;$>L)"4_JL@)/ZO5A&>L!`8[J`@D;&8GJ!0D3ZP@(FIL8
MZPD)3^JU!4_J\6@9ZP@(&QF"Z@4)$^L.#HGJ`0F<FQ[K"0E/ZK$!3^KX;AGK
M#@X;&87J`0F:&(GJ"`F>FQ+K"0E/ZOYB&>L""4_JN`@;&8'J"`+;&8+J#@);
M&4_JO@Z;&$_J^6*;&!GK#`(#8![K!@:#:0`D@F`":ACK`P.#88D8#$H*2WI$
M!F%$8`%BQ&!$8<1A1&+36!IHH9M:0`/1#?4C?;WH\(_]]S+M#E(!`!0!``#"
M10$`+>GX0X`@_?=X[1*GU^D`9Q*EU>D`10`B#_)("=GI`(G`Z0)G$:?7Z0!G
MP.D`10`D`"6"9\#I!F<.I]?I`&?`Z0I%P.D$B<#I#$7`Z0AGO>CX@P"_B:O-
M[P`````!(T5G`````/[<NI@`````=E0R$`````#PX=+#`````"WI^$^21M#I
M"KS2```G!48"ZPL&9T4(OUY%#$9/ZNIY`6O01D!K`=(!,7A!3^I8<JMO0NK)
M`D_J67Q2&,7I"F=,ZP``!?$X!RIC:&.;N[KQ/P]&W:KQ0`E/ZID:"O$!!@3K
MAA8$\4`.(48[1M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#
M^`0LZ]$H1@Q&__<J^;1"X=&IZXH:,48X1E)&_?=R[,7X>*"]Z/B/P_%`!O@8
M5D4A1JB_5D8R1OWW9.RJ;S)$JF=`*N[1*$:JZP8*-$3_]PCYM><F1M[G`+\M
MZ?!!`?$X"(]J#$8.:P5&Q_/%`X`A6AP_NC@J-KH(ZP(`"/@#$$3=PO%``@`A
M_?<.[2!&__?H^$!&."(`(?WW!NT@1B9G9V?_]][XXW@@1BMP8XAK<"-H&PJK
M<"-HZW#C>BMQ8XEK<:-H&PJK<:-HZW'C?"MR8XIK<B-I&PJK<B-IZW+C?BMS
M8XMK<Z-I&PJK<Z-IZW.4^",P*W1CC&MT(VH;"JMT(VKK=+WH\$']]^V[PO$X
M`@`A_??([,'G`+\MZ?A#!T8,3HA&#$V11GY$_?>BZWU$=ANV$`K0!#T`)%7X
M!#\!-$I&048X1IA'ID+VT;WH^(,`OTI"`0!`0@$`<$<`OP)+>T0;:/WW^;L`
MOW)$`0`(0"WI"("]Z`$``@`O=&UP`````"X```!005)?5$U01$E2``!414U0
M1$E2`%1-4`!54T52`````%5315).04U%`````"XN```E<R\E<P```"]P<F]C
M+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`%!!4E]414U0````
M`%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,24(`````
M4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4`
M``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%2
M7T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``
M,0```$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`
M````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,`````05)'5@`````8````<&5R;`````!005(Z.E!A8VME<CHZ5D524TE/
M3@`````Q+C`U,````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B
M:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T
M;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^
M)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*
M+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI0
M05(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*
M)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E
M;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I
M9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?
M1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE
M(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H
M=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]
M("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I
M>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK
M7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@
M)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K
M(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U
M9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S
M=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA
M9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A
M9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N
M<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@
M)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@
M*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B
M=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE
M9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W
M-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]
M(%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES
M='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL
M;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D
M9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,
M14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L
M("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z
M("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T
M<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`
M24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&
M:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_
M)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA
M;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*
M?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U
M;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H
M4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I
M('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I
M;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H
M+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD
M9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N
M9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["F]P96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D
M;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E
M<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>
M"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@
M96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C
M+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@
M<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]
M($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D
M<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE
M+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ
M;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S
M('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L
M:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U
M:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR
M97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R
M;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<[
M"G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD
M=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U
M:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;BAM>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I
M9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T
M('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@
M>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D
M14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/
M0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@
M,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I
M9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``
M``!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(``````8GO]_`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````H1@``&$8```!`````0``
M``$```#+`0```0```!H"```!````9@,```P```"@$@``#0```)P[```9````
MH'T!`!L````$````&@```*1]`0`<````!````/7^_V^T`0``!0```(0)```&
M````I`(```H`````!0``"P```!`````5``````````,```"X?@$``@```/@!
M```4````$0```!<```"H$```$0```,`/```2````Z````!,````(````'@``
M``@```#[__]O`0``"/[__V]@#P``____;P,```#P__]OA`X``/K__V\0````
M`````````````````````````````````````````````````````*A]`0``
M`````````*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2
M``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(`
M`*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``
MK!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L
M$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``*P2
M``"L$@``K!(``*P2``"L$@``K!(``*P2``"L$@``K!(``(D[````````````
M``````````````````````````````````````!).P```````,D5````````
M````````````````!(`!`/____^H.P``L#L```````"T.P``N#L``,`[``!$
M/```R#L```````#,.P``U#L```````#D/@``1T-#.B`H1&5B:6%N(#DN,RXP
M+3$S*2`Y+C,N,`!!,@```&%E86)I``$H````!3<M00`&"@=!"`$)`@H$$@03
M`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU
M+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!D```````````````$`````````$P````<````"````<`$`
M`'`!```D```````````````$`````````"8````'`````@```)0!``"4`0``
M(```````````````!``````````T````]O__;P(```"T`0``M`$``/`````%
M``````````0````$````/@````L````"````I`(``*0"``#@!@``!@````,`
M```$````$````$8````#`````@```(0)``"$"0````4``````````````0``
M``````!.````____;P(```"$#@``A`X``-P````%``````````(````"````
M6P```/[__V\"````8`\``&`/``!@````!@````,````$`````````&H````)
M`````@```,`/``#`#P``Z`````4`````````!`````@```!S````"0```$(`
M``"H$```J!```/@!```%````%0````0````(````?`````$````&````H!(`
M`*`2```,```````````````$`````````'<````!````!@```*P2``"L$@``
M&`,`````````````!`````0```""`````0````8```#(%0``R!4``-0E````
M``````````@`````````B`````$````&````G#L``)P[```(````````````
M```$`````````(X````!`````@```*0[``"D.P``UCT`````````````!```
M``````"6`````0``<((```!\>0``?'D```@````-``````````0`````````
MH0````$````"````A'D``(1Y```$```````````````$`````````*L````.
M`````P```*!]`0"@?0``!```````````````!`````0```"W````#P````,`
M``"D?0$`I'T```0```````````````0````$````PP````8````#````J'T!
M`*A]```0`0``!@`````````$````"````,P````!`````P```+A^`0"X?@``
M2`$`````````````!`````0```#1`````0````,`````@`$``(```$``````
M``````````0`````````UP````@````#````0(`!`$"````8$```````````
M```$`````````-P````!````,`````````!`@```'0```````````````0``
M``$```#E`````P``<```````````78```#,```````````````$`````````
H`0````,``````````````)"```#U```````````````!````````````
